pub enum Error {
Success,
BufferTooShort {
required: usize,
had: usize,
},
InvalidFieldNumber {
field_number: u32,
what: String,
},
UnhandledWireType {
wire_type: u32,
},
TagTooLarge {
tag: u64,
},
VarintOverflow {
bytes: usize,
},
UnsignedOverflow {
value: u64,
},
SignedOverflow {
value: i64,
},
WrongLength {
required: usize,
had: usize,
},
StringEncoding,
UnknownDiscriminant {
discriminant: u32,
},
NotAChar {
value: u32,
},
}Expand description
Error captures the possible error conditions for packing and unpacking.
Variants
Success
The default error is succes.
BufferTooShort
BufferTooShort indicates that there was a need to pack or unpack more bytes than were available in the underlying memory.
Fields
InvalidFieldNumber
InvalidFieldNumber indicates that the field is not a user-assignable field.
Fields
UnhandledWireType
UnhandledWireType indicates that the wire_type is not understood by this process and cannot be skipped.
TagTooLarge
TagTooLarge indicates the tag would overflow a 32-bit number.
VarintOverflow
VarintOverflow indicates that a varint field did not terminate with a number < 128.
UnsignedOverflow
UnsignedOverflow indicates that a value will not fit its intended (unsigned) target.
SignedOverflow
SignedOverflow indicates that a value will not fit its intended (signed) target.
WrongLength
WrongLength indicates that a bytes32 did not have 32 bytes.
Fields
StringEncoding
StringEncoding indicates that a value is not UTF-8 friendly.
UnknownDiscriminant
UnknownDiscriminant indicates a variant that is not understood by this code.
NotAChar
NotAChar indicates that the prescribed value was tried to unpack as a char, but it’s not a char.